import React, { CSSProperties, HTMLAttributes, MouseEvent, WheelEvent } from 'react';
import { Elements, NodeTypesType, EdgeTypesType, OnLoadFunc, Node, Edge, Connection, ConnectionLineType, ConnectionLineComponent, FlowTransform, OnConnectStartFunc, OnConnectStopFunc, OnConnectEndFunc, TranslateExtent } from '../../types';
import '../../style.css';
export interface ReactFlowProps extends Omit<HTMLAttributes<HTMLDivElement>, 'onLoad'> {
    elements: Elements;
    onElementClick?: (event: MouseEvent, element: Node | Edge) => void;
    onElementsRemove?: (elements: Elements) => void;
    onNodeMouseEnter?: (event: MouseEvent, node: Node) => void;
    onNodeMouseMove?: (event: MouseEvent, node: Node) => void;
    onNodeMouseLeave?: (event: MouseEvent, node: Node) => void;
    onNodeContextMenu?: (event: MouseEvent, node: Node) => void;
    onNodeDragStart?: (event: MouseEvent, node: Node) => void;
    onNodeDragStop?: (event: MouseEvent, node: Node) => void;
    onConnect?: (connection: Edge | Connection) => void;
    onConnectStart?: OnConnectStartFunc;
    onConnectStop?: OnConnectStopFunc;
    onConnectEnd?: OnConnectEndFunc;
    onLoad?: OnLoadFunc;
    onMove?: (flowTransform?: FlowTransform) => void;
    onMoveStart?: (flowTransform?: FlowTransform) => void;
    onMoveEnd?: (flowTransform?: FlowTransform) => void;
    onSelectionChange?: (elements: Elements | null) => void;
    onSelectionDragStart?: (event: MouseEvent, nodes: Node[]) => void;
    onSelectionDrag?: (event: MouseEvent, nodes: Node[]) => void;
    onSelectionDragStop?: (event: MouseEvent, nodes: Node[]) => void;
    onSelectionContextMenu?: (event: MouseEvent, nodes: Node[]) => void;
    onPaneScroll?: (event?: WheelEvent) => void;
    onPaneClick?: (event: MouseEvent) => void;
    onPaneContextMenu?: (event: MouseEvent) => void;
    nodeTypes: NodeTypesType;
    edgeTypes: EdgeTypesType;
    connectionLineType: ConnectionLineType;
    connectionLineStyle?: CSSProperties;
    connectionLineComponent?: ConnectionLineComponent;
    deleteKeyCode: number;
    selectionKeyCode: number;
    snapToGrid: boolean;
    snapGrid: [number, number];
    onlyRenderVisibleNodes: boolean;
    nodesDraggable: boolean;
    nodesConnectable: boolean;
    elementsSelectable: boolean;
    selectNodesOnDrag: boolean;
    paneMoveable: boolean;
    minZoom: number;
    maxZoom: number;
    defaultZoom: number;
    defaultPosition: [number, number];
    translateExtent?: TranslateExtent;
    arrowHeadColor: string;
    markerEndId?: string;
    zoomOnScroll: boolean;
    zoomOnDoubleClick: boolean;
}
declare const ReactFlow: {
    ({ style, onElementClick, elements, className, children, nodeTypes, edgeTypes, onLoad, onMove, onMoveStart, onMoveEnd, onElementsRemove, onConnect, onConnectStart, onConnectStop, onConnectEnd, onNodeMouseEnter, onNodeMouseMove, onNodeMouseLeave, onNodeContextMenu, onNodeDragStart, onNodeDragStop, onSelectionChange, onSelectionDragStart, onSelectionDrag, onSelectionDragStop, onSelectionContextMenu, connectionLineType, connectionLineStyle, connectionLineComponent, deleteKeyCode, selectionKeyCode, snapToGrid, snapGrid, onlyRenderVisibleNodes, nodesDraggable, nodesConnectable, elementsSelectable, selectNodesOnDrag, minZoom, maxZoom, defaultZoom, defaultPosition, translateExtent, arrowHeadColor, markerEndId, zoomOnScroll, zoomOnDoubleClick, paneMoveable, onPaneClick, onPaneScroll, onPaneContextMenu, }: ReactFlowProps): JSX.Element;
    displayName: string;
    defaultProps: {
        nodeTypes: {
            input: React.MemoExoticComponent<{
                ({ data, isConnectable, sourcePosition }: import("../../types").NodeProps): JSX.Element;
                displayName: string;
            }>;
            default: React.MemoExoticComponent<{
                ({ data, isConnectable, targetPosition, sourcePosition, }: import("../../types").NodeProps): JSX.Element;
                displayName: string;
            }>;
            output: React.MemoExoticComponent<{
                ({ data, isConnectable, targetPosition }: import("../../types").NodeProps): JSX.Element;
                displayName: string;
            }>;
        };
        edgeTypes: {
            default: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, sourcePosition, targetPosition, label, labelStyle, labelShowBg, labelBgStyle, labelBgPadding, labelBgBorderRadius, style, arrowHeadType, markerEndId, }: import("../../types").EdgeProps) => JSX.Element>;
            straight: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, label, labelStyle, labelShowBg, labelBgStyle, labelBgPadding, labelBgBorderRadius, style, arrowHeadType, markerEndId, }: import("../../types").EdgeProps) => JSX.Element>;
            step: React.MemoExoticComponent<(props: import("../../types").EdgeSmoothStepProps) => JSX.Element>;
            smoothstep: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, label, labelStyle, labelShowBg, labelBgStyle, labelBgPadding, labelBgBorderRadius, style, sourcePosition, targetPosition, arrowHeadType, markerEndId, borderRadius, }: import("../../types").EdgeSmoothStepProps) => JSX.Element>;
        };
        connectionLineType: ConnectionLineType;
        deleteKeyCode: number;
        selectionKeyCode: number;
        snapToGrid: boolean;
        snapGrid: number[];
        onlyRenderVisibleNodes: boolean;
        nodesDraggable: boolean;
        nodesConnectable: boolean;
        elementsSelectable: boolean;
        selectNodesOnDrag: boolean;
        paneMoveable: boolean;
        minZoom: number;
        maxZoom: number;
        defaultZoom: number;
        defaultPosition: number[];
        arrowHeadColor: string;
        zoomOnScroll: boolean;
        zoomOnDoubleClick: boolean;
    };
};
export default ReactFlow;
